import React from 'react';
import { useEffect } from 'react';
import { Search, Settings, Rocket, LineChart, Bot, ArrowRight, BrainCircuit, Target, Zap, CheckCircle2, Users, MessageSquare } from 'lucide-react';
import { Link, useNavigate } from 'react-router-dom'; 
import Footer from '../components/Footer';

const ProcessPage = () => {
  useEffect(() => {
    document.title = 'Our Process - Seamless AI Communication Implementation | Sales Assist AI';
    const metaDescription = document.querySelector('meta[name="description"]');
    if (metaDescription) {
      metaDescription.setAttribute('content', 'Discover our proven 5-step implementation process for AI communication systems. From initial discovery to continuous optimization, we ensure a smooth transition to intelligent automation that drives results.');
    }
    window.scrollTo({ top: 0, behavior: 'smooth' });
  }, []);

  const navigate = useNavigate();

  const handleNavigation = (path: string) => {
    if (path.startsWith('#')) {
      navigate('/');
      setTimeout(() => {
        const element = document.querySelector(path);
        element?.scrollIntoView({ behavior: 'smooth' });
      }, 100);
    } else {
      navigate(path);
    }
  };

  const steps = [
    {
      icon: <Search className="w-6 h-6" />,
      title: 'Discovery & Strategy',
      description: 'We analyze your communication needs and design a comprehensive strategy for seamless customer engagement across all channels.',
      details: [
        { icon: <Target className="w-4 h-4" />, text: 'Business process analysis' },
        { icon: <MessageSquare className="w-4 h-4" />, text: 'Communication channel audit' },
        { icon: <BrainCircuit className="w-4 h-4" />, text: 'Custom strategy development' },
        { icon: <LineChart className="w-4 h-4" />, text: 'ROI projection and goals' }
      ]
    },
    {
      icon: <Settings className="w-6 h-6" />,
      title: 'Seamless Setup',
      description: 'We integrate with your existing phone systems, social media, messaging apps, and more creating a unified communication hub.',
      details: [
        { icon: <Zap className="w-4 h-4" />, text: 'Platform integration' },
        { icon: <Settings className="w-4 h-4" />, text: 'Data migration' },
        { icon: <Bot className="w-4 h-4" />, text: 'System configuration' },
        { icon: <CheckCircle2 className="w-4 h-4" />, text: 'Security setup' }
      ]
    },
    {
      icon: <Bot className="w-6 h-6" />,
      title: 'AI Communication Setup',
      description: 'We configure your AI assistant to handle inquiries, qualify leads, and maintain engaging conversations across all channels.',
      details: [
        { icon: <BrainCircuit className="w-4 h-4" />, text: 'AI model training' },
        { icon: <MessageSquare className="w-4 h-4" />, text: 'Response customization' },
        { icon: <Settings className="w-4 h-4" />, text: 'Workflow automation' },
        { icon: <CheckCircle2 className="w-4 h-4" />, text: 'Quality assurance' }
      ]
    },
    {
      icon: <Rocket className="w-6 h-6" />,
      title: 'Hands-On Launch',
      description: 'We ensure your AI assistant is perfectly calibrated for your business before activating 24/7 automated communication.',
      details: [
        { icon: <Target className="w-4 h-4" />, text: 'System testing' },
        { icon: <Users className="w-4 h-4" />, text: 'Team training' },
        { icon: <Rocket className="w-4 h-4" />, text: 'Gradual rollout' },
        { icon: <LineChart className="w-4 h-4" />, text: 'Performance monitoring' }
      ]
    },
    {
      icon: <LineChart className="w-6 h-6" />,
      title: 'Ongoing Optimization',
      description: 'We monitor performance across all channels, fine-tuning responses and strategies to maximize engagement and conversions.',
      details: [
        { icon: <LineChart className="w-4 h-4" />, text: 'Performance analytics' },
        { icon: <Zap className="w-4 h-4" />, text: 'Continuous improvement' },
        { icon: <Target className="w-4 h-4" />, text: 'Strategy refinement' },
        { icon: <LineChart className="w-4 h-4" />, text: 'ROI tracking' }
      ]
    }
  ];

  return (
    <div className="min-h-screen bg-gradient-to-b from-white via-primary-50/30 to-white">
      <div className="container pt-24 pb-12">
        <div className="text-center mb-12">
          <div className="inline-flex items-center gap-2 px-4 py-2 rounded-full bg-primary-50 border border-primary-100 mb-4">
            <div className="p-1 bg-gradient-to-r from-primary-500 to-primary-600 rounded-full">
              <Settings className="w-4 h-4 text-white" />
            </div>
            <span className="text-sm font-medium text-primary-700">
              OUR PROCESS
            </span>
          </div>
          
          <h1 className="text-4xl sm:text-5xl font-bold text-secondary-900 mb-4">
            Our Done-For-You
            <span className="block text-gradient mt-2">Implementation Process</span>
          </h1>
          <p className="text-xl text-secondary-600 max-w-2xl mx-auto">
            We handle every aspect of your AI-powered communication and sales automation, from setup to optimization
          </p>
        </div>

        <div className="max-w-5xl mx-auto">
          <div className="space-y-12">
            {steps.map((step, index) => (
              <div key={index} className="relative">
                {/* Connection line */}
                {index < steps.length - 1 && (
                  <div className="absolute left-8 lg:left-12 top-28 bottom-0 w-px bg-gradient-to-b from-primary-200 via-primary-300 to-primary-200 animate-pulse" />
                )}
                
                <div className="group relative bg-white/90 backdrop-blur-sm rounded-3xl border border-primary-100/50 shadow-soft p-8 hover:shadow-lg transition-all">
                  <div className="absolute inset-0 bg-gradient-to-br from-primary-50/0 via-primary-50/30 to-primary-50/0 -translate-x-full group-hover:translate-x-full transition-transform duration-1000" />
                  
                  <div className="relative">
                    <div className="flex items-start gap-8">
                      {/* Step Number */}
                      <div className="flex-shrink-0 w-16 lg:w-24 h-16 lg:h-24 rounded-2xl bg-gradient-to-br from-primary-50 to-primary-100/50 border-2 border-primary-100/50 flex items-center justify-center group-hover:scale-110 transition-transform">
                        <span className="text-2xl lg:text-3xl font-bold bg-gradient-to-br from-primary-600 to-primary-500 bg-clip-text text-transparent">
                          {index + 1}
                        </span>
                      </div>

                      <div className="flex-1">
                        {/* Icon and Title */}
                        <div className="flex items-center gap-4 mb-4">
                          <div className="w-12 h-12 rounded-xl bg-gradient-to-br from-primary-50 to-primary-100/50 flex items-center justify-center text-primary-600 group-hover:scale-110 transition-transform">
                            {step.icon}
                          </div>
                          <h3 className="text-2xl font-semibold text-secondary-900 group-hover:text-gradient transition-colors">
                            {step.title}
                          </h3>
                        </div>

                        {/* Description */}
                        <p className="text-lg text-secondary-600 mb-6">
                          {step.description}
                        </p>

                        {/* Details Grid */}
                        <div className="grid sm:grid-cols-2 gap-4 relative">
                          <div className="absolute inset-0 bg-gradient-to-br from-primary-50/0 via-primary-50/20 to-primary-50/0 opacity-0 group-hover:opacity-100 transition-opacity duration-500 rounded-xl" />
                          {step.details.map((detail, idx) => (
                            <div key={idx} className="group/detail flex items-center gap-3 bg-primary-50/50 rounded-xl p-3 border border-primary-100/50 hover:shadow-md transition-all">
                              <div className="w-8 h-8 rounded-lg bg-white flex items-center justify-center text-primary-600 group-hover/detail:scale-110 transition-transform">
                                {detail.icon}
                              </div>
                              <span className="text-sm font-medium text-primary-900">{detail.text}</span>
                            </div>
                          ))}
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            ))}
          </div>

          {/* CTA Section */}
          <div className="relative mt-16 text-center">
            <div className="absolute inset-0 bg-gradient-to-br from-primary-500/5 to-primary-600/5 rounded-3xl blur-xl" />
            <div className="relative bg-white/90 backdrop-blur-sm rounded-3xl border border-primary-100/50 shadow-soft p-8 sm:p-12">
            <h2 className="text-3xl font-bold text-secondary-900 mb-4">
              Ready to Get Started?
              <span className="block text-gradient mt-2">Let's Transform Your Business</span>
            </h2>
            <p className="text-lg text-secondary-600 mb-8 max-w-2xl mx-auto leading-relaxed">
              Book a personalized demo to see how our AI-powered platform can transform your business communication and drive growth.
            </p>
            <div className="flex justify-center">
              <Link
                to="/book-demo"
                className="btn-primary group text-lg px-8 py-4"
              >
                Book a Demo
                <ArrowRight className="ml-2 w-5 h-5 group-hover:translate-x-0.5 transition-transform" />
              </Link>
            </div>
            </div>
          </div>
        </div>
      </div>
      <Footer />
    </div>
  );
};

export default ProcessPage;